#!/bin/sh
#
# Sets up the Allegro package for building with the specified compiler,
# and if possible converting text files from CR/LF to LF format.

proc_bcc32()
{
   AL_COMPILER="Windows (BCC32)"
   AL_MAKEFILE="makefile.bcc"
   AL_PLATFORM="ALLEGRO_BCC32"
}

proc_beos()
{
   AL_COMPILER="BeOS"
   AL_MAKEFILE="makefile.be"
   AL_PLATFORM="ALLEGRO_BEOS"
}

proc_djgpp()
{
   AL_COMPILER="DOS (djgpp)"
   AL_MAKEFILE="makefile.dj"
   AL_PLATOFRM="ALLEGRO_DJGPP"
}

proc_mingw32()
{
   AL_COMPILER="Windows (Mingw32)"
   AL_MAKEFILE="makefile.mgw"
   AL_PLATFORM="ALLEGRO_MINGW32"
}

proc_msvc()
{
   AL_COMPILER="Windows (MSVC)"
   AL_MAKEFILE="makefile.vc"
   AL_PLATFORM="ALLEGRO_MSVC"
}

proc_qnx()
{
   AL_COMPILER="QNX"
   AL_MAKEFILE="makefile.qnx"
   AL_PLATFORM="ALLEGRO_QNX"
}

proc_rsxnt()
{
   AL_COMPILER="Windows (RSXNT)"
   AL_MAKEFILE="makefile.rsx"
   AL_PLATFORM="ALLEGRO_RSXNT"
}

proc_unix()
{
   AL_COMPILER="Unix"
   AL_MAKEFILE="dummy"
   AL_PLATFORM="ALLEGRO_UNIX"
   AL_NOMAKE="1"
   chmod +x configure *.sh misc/*.sh misc/*.pl
}

proc_watcom()
{
   AL_COMPILER="DOS (Watcom)"
   AL_MAKEFILE="makefile.wat"
   AL_PLATFORM="ALLEGRO_WATCOM"
}

proc_help()
{
   echo "Usage: ./fix.sh <platform> [--quick|--dtou|--utod]"
   echo ""
   echo "Where platform is one of: bcc32, beos, djgpp, mingw32, msvc, qnx, rsxnt, unix"
   echo "and watcom."
   echo "The --quick parameter turns of text file conversion, --dtou converts from DOS/Win32"
   echo "format to unix and --utod converts from unix to DOS/Win32 format."
   echo "If no parameter is specified --dtou is assumed."
}

proc_fix()
{
   echo "Configuring Allegro for $AL_COMPILER..."

   if [ "$AL_NOMAKE" != "1"]; then
      echo "# generated by fix.sh" > makefile
      echo "MAKEFILE_INC = $AL_MAKEFILE" >> makefile
      echo "include makefile.all" >> makefile
   fi

   echo "/* generated by fix.sh */" > include/allegro/alplatf.h
   echo "#define $AL_PLATFORM" >> include/allegro/alplatf.h
}

proc_utod()
{
   for file in "*.bat .../*.c *.cfg .../*.h .../*.inc .../*.s .../*.txt .../*._tx makefile.* readme.*"; do
      if echo $file | grep -q "^\.\.\./"; then
	 # files like .../*.c recurse into directories (emulating djgpp libc)
	 spec=$(echo $file | sed -e "s/^\.\.\.\///")
	 find . -type f -name "$spec" -exec perl -p -i -e 's/([^\r]|^)\n/\1\r\n/' {} \;
      else
	 perl -p -i -e "s/([^\r]|^)\n/\1\r\n/" $file
      fi
   done
}

proc_dtou()
{
   find . -type f "(" \
      -name "*.c" -o -name "*.cfg" -o -name "*.cpp" -o -name "*.dep" -o \
      -name "*.h" -o -name "*.hin" -o -name "*.in" -o -name "*.inc" -o \
      -name "*.m4" -o -name "*.mft" -o -name "*.s" -o -name "*.sh" -o \
      -name "*.spec" -o -name "*.pl" -o -name "*.txt" -o -name "*._tx" -o \
      -name "makefile.*" -o -name "readme.*" \
      ")" \
      -exec sh -c "echo {};
		   mv {} _tmpfile;
		   tr -d \\\r < _tmpfile > {};
		   touch -r _tmpfile {}; 
		   rm _tmpfile" \;
}

# take action!

if [ "$1" = "bcc32" ]; then
   proc_bcc32
   fix
elif [ "$1" = "beos" ]; then
   proc_beos
   fix
elif [ "$1" = "djgpp" ]; then
   proc_djgpp
   fix
elif [ "$1" = "mingw32" ]; then
   proc_mingw32
   fix
elif [ "$1" = "msvc" ]; then
   proc_msvc
   fix
elif [ "$1" = "qnx" ]; then
   proc_qnx
   fix
elif [ "$1" = "rsxnt" ]; then
   proc_rsxnt
   fix
elif [ "$1" = "unix" ]; then
   proc_unix
   fix
elif [ "$1" = "watcom" ]; then
   proc_watcom
   fix
elif [ "$1" = "help" ]; then
   proc_help
elif [ "$1" = "" ]; then
   proc_help
fi

# someone ordered a text conversion?

if [ "$2" = "--quick" ]; then
   echo "No text file conversion..."
elif [ $2 = "--utod" ]; then
   echo "Converting files from Unix to DOS/Win32..."
   proc_utod
elif [ $2 = "--dtou" ]; then
   echo "Converting files from DOS/Win32 to Unix..."
   proc_dtou
fi

echo "Done!"
